@@ -1,4 +1,4 @@
-from gitirods.util import getRepo
+from gitirods.util import getRepo, projectExists
 from gitirods.project import createProjectCol
 from gitirods.check_point import executeCheckPoint
 
@@ -10,10 +10,12 @@ def main():
     then creates a collection in iRODS for the repository name
     otherwise executes the check point function
     """
-
+   
     try:
         repo, _ = getRepo()
         repo.commit('HEAD~1')
+        if projectExists(repo):
+            createProjectCol()
     except Exception as err:
         if err.args == ("Invalid revision spec 'HEAD~1^0' - not enough parent commits to reach '~1'",):
             createProjectCol()
